@@ -8,10 +8,11 @@ config_obj = ConfigParser()
 parser = config_obj.read(path.join(Path.home(), ".pyGinitconfig.ini"))
 
 
-def execute_git(username, token, repo_name):
+def execute_git(username, token, repo_name,remote_name):
     """
     initialize git repository and push to remote
     """
+    remote_name = "origin" if remote_name.isspace() else remote_name
     url = "https://{username}:{token}@github.com/{username}/{repo_name}.git".format(
         username=username, repo_name=repo_name.replace(" ", "-"), token=token
     )
@@ -19,5 +20,5 @@ def execute_git(username, token, repo_name):
     repo.git.add("--all")
     repo.index.commit("initial commit")
     repo.git.push(url, "HEAD:master")
-    repo.create_remote("origin", url)
-    print("remote name : origin \nurl :" + url)
+    repo.create_remote(remote_name, url)
+    print("remote name :"+ remote_name+ "\nurl :" + url)
